Module: Paperclip

Defined in:
lib/paperclip_processors/metadata_extractor.rb

Overview

This assumes that you are using paperclip. For example you may Video model with an attachment of video. truncated example: class Video has_attached_file :video, :styles => => {}, :processors => [:metadata_extractor] end

Remember for processors to work you must define styles on has_attached_file. Even if they are just blank as the example above. Without them processors won't be triggered.

Defined Under Namespace

Classes: MetadataExtractor